@@ -23,8 +23,9 @@ DEALINGS IN THE SOFTWARE.
 """
 
 from __future__ import annotations
-import logging
 import inspect
+import sys
+import traceback
 
 from typing import (
     Any,
@@ -56,11 +57,9 @@ from .errors import (
     CommandNotFound,
     CommandSignatureMismatch,
     CommandLimitReached,
-    CommandSyncFailure,
     MissingApplicationID,
 )
-from .translator import Translator, locale_str
-from ..errors import ClientException, HTTPException
+from ..errors import ClientException
 from ..enums import AppCommandType, InteractionType
 from ..utils import MISSING, _get_as_snowflake, _is_submodule
 
@@ -80,8 +79,6 @@ __all__ = ('CommandTree',)
 
 ClientT = TypeVar('ClientT', bound='Client')
 
-_log = logging.getLogger(__name__)
-
 
 def _retrieve_guild_ids(
     command: Any, guild: Optional[Snowflake] = MISSING, guilds: Sequence[Snowflake] = MISSING
@@ -346,7 +343,7 @@ class CommandTree(Generic[ClientT]):
                 self._context_menus.update(current)
             return
         elif not isinstance(command, (Command, Group)):
-            raise TypeError(f'Expected an application command, received {command.__class__!r} instead')
+            raise TypeError(f'Expected a application command, received {command.__class__!r} instead')
 
         # todo: validate application command groups having children (required)
 
@@ -540,7 +537,7 @@ class CommandTree(Generic[ClientT]):
         guild: Optional[Snowflake] = None,
         type: AppCommandType = AppCommandType.chat_input,
     ) -> Optional[Union[Command[Any, ..., Any], ContextMenu, Group]]:
-        """Gets an application command from the tree.
+        """Gets a application command from the tree.
 
         Parameters
         -----------
@@ -778,8 +775,8 @@ class CommandTree(Generic[ClientT]):
 
         A callback that is called when any command raises an :exc:`AppCommandError`.
 
-        The default implementation logs the exception using the library logger
-        if the command does not have any error handlers attached to it.
+        The default implementation prints the traceback to stderr if the command does
+        not have any error handlers attached to it.
 
         To get the command that failed, :attr:`discord.Interaction.command` should
         be used.
@@ -797,9 +794,11 @@ class CommandTree(Generic[ClientT]):
             if command._has_any_error_handlers():
                 return
 
-            _log.error('Ignoring exception in command %r', command.name, exc_info=error)
+            print(f'Ignoring exception in command {command.name!r}:', file=sys.stderr)
         else:
-            _log.error('Ignoring exception in command tree', exc_info=error)
+            print(f'Ignoring exception in command tree:', file=sys.stderr)
+
+        traceback.print_exception(error.__class__, error, error.__traceback__, file=sys.stderr)
 
     def error(self, coro: ErrorFunc) -> ErrorFunc:
         """A decorator that registers a coroutine as a local error handler.
@@ -834,22 +833,20 @@ class CommandTree(Generic[ClientT]):
     def command(
         self,
         *,
-        name: Union[str, locale_str] = MISSING,
-        description: Union[str, locale_str] = MISSING,
+        name: str = MISSING,
+        description: str = MISSING,
         nsfw: bool = False,
         guild: Optional[Snowflake] = MISSING,
         guilds: Sequence[Snowflake] = MISSING,
-        auto_locale_strings: bool = True,
-        extras: Dict[Any, Any] = MISSING,
     ) -> Callable[[CommandCallback[Group, P, T]], Command[Group, P, T]]:
         """Creates an application command directly under this tree.
 
         Parameters
         ------------
-        name: Union[:class:`str`, :class:`locale_str`]
+        name: :class:`str`
             The name of the application command. If not given, it defaults to a lower-case
             version of the callback name.
-        description: Union[:class:`str`, :class:`locale_str`]
+        description: :class:`str`
             The description of the application command. This shows up in the UI to describe
             the application command. If not given, it defaults to the first line of the docstring
             of the callback shortened to 100 characters.
@@ -864,15 +861,6 @@ class CommandTree(Generic[ClientT]):
             The list of guilds to add the command to. This cannot be mixed
             with the ``guild`` parameter. If no guilds are given at all
             then it becomes a global command instead.
-        auto_locale_strings: :class:`bool`
-            If this is set to ``True``, then all translatable strings will implicitly
-            be wrapped into :class:`locale_str` rather than :class:`str`. This could
-            avoid some repetition and be more ergonomic for certain defaults such
-            as default command names, command descriptions, and parameter names.
-            Defaults to ``True``.
-        extras: :class:`dict`
-            A dictionary that can be used to store extraneous data.
-            The library will not touch any values or keys within this dictionary.
         """
 
         def decorator(func: CommandCallback[Group, P, T]) -> Command[Group, P, T]:
@@ -893,8 +881,6 @@ class CommandTree(Generic[ClientT]):
                 callback=func,
                 nsfw=nsfw,
                 parent=None,
-                auto_locale_strings=auto_locale_strings,
-                extras=extras,
             )
             self.add_command(command, guild=guild, guilds=guilds)
             return command
@@ -904,14 +890,12 @@ class CommandTree(Generic[ClientT]):
     def context_menu(
         self,
         *,
-        name: Union[str, locale_str] = MISSING,
+        name: str = MISSING,
         nsfw: bool = False,
         guild: Optional[Snowflake] = MISSING,
         guilds: Sequence[Snowflake] = MISSING,
-        auto_locale_strings: bool = True,
-        extras: Dict[Any, Any] = MISSING,
     ) -> Callable[[ContextMenuCallback], ContextMenu]:
-        """Creates an application command context menu from a regular function directly under this tree.
+        """Creates a application command context menu from a regular function directly under this tree.
 
         This function must have a signature of :class:`~discord.Interaction` as its first parameter
         and taking either a :class:`~discord.Member`, :class:`~discord.User`, or :class:`~discord.Message`,
@@ -932,7 +916,7 @@ class CommandTree(Generic[ClientT]):
 
         Parameters
         ------------
-        name: Union[:class:`str`, :class:`locale_str`]
+        name: :class:`str`
             The name of the context menu command. If not given, it defaults to a title-case
             version of the callback name. Note that unlike regular slash commands this can
             have spaces and upper case characters in the name.
@@ -947,15 +931,6 @@ class CommandTree(Generic[ClientT]):
             The list of guilds to add the command to. This cannot be mixed
             with the ``guild`` parameter. If no guilds are given at all
             then it becomes a global command instead.
-        auto_locale_strings: :class:`bool`
-            If this is set to ``True``, then all translatable strings will implicitly
-            be wrapped into :class:`locale_str` rather than :class:`str`. This could
-            avoid some repetition and be more ergonomic for certain defaults such
-            as default command names, command descriptions, and parameter names.
-            Defaults to ``True``.
-        extras: :class:`dict`
-            A dictionary that can be used to store extraneous data.
-            The library will not touch any values or keys within this dictionary.
         """
 
         def decorator(func: ContextMenuCallback) -> ContextMenu:
@@ -963,66 +938,17 @@ class CommandTree(Generic[ClientT]):
                 raise TypeError('context menu function must be a coroutine function')
 
             actual_name = func.__name__.title() if name is MISSING else name
-            context_menu = ContextMenu(
-                name=actual_name,
-                nsfw=nsfw,
-                callback=func,
-                auto_locale_strings=auto_locale_strings,
-                extras=extras,
-            )
+            context_menu = ContextMenu(name=actual_name, nsfw=nsfw, callback=func)
             self.add_command(context_menu, guild=guild, guilds=guilds)
             return context_menu
 
         return decorator
 
-    @property
-    def translator(self) -> Optional[Translator]:
-        """Optional[:class:`Translator`]: The translator, if any, responsible for handling translation of commands.
-
-        To change the translator, use :meth:`set_translator`.
-        """
-        return self._state._translator
-
-    async def set_translator(self, translator: Optional[Translator]) -> None:
-        """Sets the translator to use for translating commands.
-
-        If a translator was previously set, it will be unloaded using its
-        :meth:`Translator.unload` method.
-
-        When a translator is set, it will be loaded using its :meth:`Translator.load` method.
-
-        Parameters
-        ------------
-        translator: Optional[:class:`Translator`]
-            The translator to use. If ``None`` then the translator is just removed and unloaded.
-
-        Raises
-        -------
-        TypeError
-            The translator was not ``None`` or a :class:`Translator` instance.
-        """
-
-        if translator is not None and not isinstance(translator, Translator):
-            raise TypeError(f'expected None or Translator instance, received {translator.__class__!r} instead')
-
-        old_translator = self._state._translator
-        if old_translator is not None:
-            await old_translator.unload()
-
-        if translator is None:
-            self._state._translator = None
-        else:
-            await translator.load()
-            self._state._translator = translator
-
     async def sync(self, *, guild: Optional[Snowflake] = None) -> List[AppCommand]:
         """|coro|
 
         Syncs the application commands to Discord.
 
-        This also runs the translator to get the translated strings necessary for
-        feeding back into Discord.
-
         This must be called for the application commands to show up.
 
         Parameters
@@ -1035,16 +961,10 @@ class CommandTree(Generic[ClientT]):
         -------
         HTTPException
             Syncing the commands failed.
-        CommandSyncFailure
-            Syncing the commands failed due to a user related error, typically because
-            the command has invalid data. This is equivalent to an HTTP status code of
-            400.
         Forbidden
             The client does not have the ``applications.commands`` scope in the guild.
         MissingApplicationID
             The client does not have an application ID.
-        TranslationError
-            An error occurred while translating the commands.
 
         Returns
         --------
@@ -1056,38 +976,20 @@ class CommandTree(Generic[ClientT]):
             raise MissingApplicationID
 
         commands = self._get_all_commands(guild=guild)
-
-        translator = self.translator
-        if translator:
-            payload = [await command.get_translated_payload(translator) for command in commands]
+        payload = [command.to_dict() for command in commands]
+        if guild is None:
+            data = await self._http.bulk_upsert_global_commands(self.client.application_id, payload=payload)
         else:
-            payload = [command.to_dict() for command in commands]
-
-        try:
-            if guild is None:
-                data = await self._http.bulk_upsert_global_commands(self.client.application_id, payload=payload)
-            else:
-                data = await self._http.bulk_upsert_guild_commands(self.client.application_id, guild.id, payload=payload)
-        except HTTPException as e:
-            if e.status == 400:
-                raise CommandSyncFailure(e, commands) from None
-            raise
+            data = await self._http.bulk_upsert_guild_commands(self.client.application_id, guild.id, payload=payload)
 
         return [AppCommand(data=d, state=self._state) for d in data]
 
-    async def _dispatch_error(self, interaction: Interaction, error: AppCommandError, /) -> None:
-        command = interaction.command
-        if isinstance(command, Command):
-            await command._invoke_error_handlers(interaction, error)
-        else:
-            await self.on_error(interaction, error)
-
-    def _from_interaction(self, interaction: Interaction) -> None:
+    def _from_interaction(self, interaction: Interaction):
         async def wrapper():
             try:
-                await self._call(interaction)
+                await self.call(interaction)
             except AppCommandError as e:
-                await self._dispatch_error(interaction, e)
+                await self.on_error(interaction, e)
 
         self.client.loop.create_task(wrapper(), name='CommandTree-invoker')
 
@@ -1157,9 +1059,6 @@ class CommandTree(Generic[ClientT]):
         name = data['name']
         guild_id = _get_as_snowflake(data, 'guild_id')
         ctx_menu = self._context_menus.get((name, guild_id, type))
-        if ctx_menu is None and self.fallback_to_global:
-            ctx_menu = self._context_menus.get((name, None, type))
-
         # Pre-fill the cached slot to prevent re-computation
         interaction._cs_command = ctx_menu
 
@@ -1201,7 +1100,29 @@ class CommandTree(Generic[ClientT]):
         """
         return True
 
-    async def _call(self, interaction: Interaction) -> None:
+    async def call(self, interaction: Interaction) -> None:
+        """|coro|
+
+        Given an :class:`~discord.Interaction`, calls the matching
+        application command that's being invoked.
+
+        This is usually called automatically by the library.
+
+        Parameters
+        -----------
+        interaction: :class:`~discord.Interaction`
+            The interaction to dispatch from.
+
+        Raises
+        --------
+        CommandNotFound
+            The application command referred to could not be found.
+        CommandSignatureMismatch
+            The interaction data referred to a parameter that was not found in the
+            application command definition.
+        AppCommandError
+            An error occurred while calling the command.
+        """
         if not await self.interaction_check(interaction):
             return
 
@@ -1235,5 +1156,5 @@ class CommandTree(Generic[ClientT]):
         try:
             await command._invoke_with_namespace(interaction, namespace)
         except AppCommandError as e:
-            await command._invoke_error_handlers(interaction, e)
+            await command._invoke_error_handler(interaction, e)
             await self.on_error(interaction, e)
