@@ -58,6 +58,8 @@ from .parameters import Parameter, Signature
 if TYPE_CHECKING:
     from typing_extensions import Concatenate, ParamSpec, Self
 
+    from discord.message import Message
+
     from ._types import BotT, Check, ContextT, Coro, CoroFunc, Error, Hook, UserCheck
 
 
@@ -91,9 +93,9 @@ __all__ = (
 MISSING: Any = discord.utils.MISSING
 
 T = TypeVar('T')
-CommandT = TypeVar('CommandT', bound='Command[Any, ..., Any]')
+CommandT = TypeVar('CommandT', bound='Command')
 # CHT = TypeVar('CHT', bound='Check')
-GroupT = TypeVar('GroupT', bound='Group[Any, ..., Any]')
+GroupT = TypeVar('GroupT', bound='Group')
 
 if TYPE_CHECKING:
     P = ParamSpec('P')
@@ -165,6 +167,9 @@ def get_signature_parameters(
             if len(metadata) >= 1:
                 annotation = metadata[0]
 
+        if isinstance(annotation, discord.app_commands.transformers._TransformMetadata):
+            annotation = annotation.metadata
+
         params[name] = parameter.replace(annotation=annotation)
 
     return params
@@ -349,8 +354,8 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
     def __init__(
         self,
         func: Union[
-            Callable[Concatenate[CogT, Context[Any], P], Coro[T]],
-            Callable[Concatenate[Context[Any], P], Coro[T]],
+            Callable[Concatenate[CogT, ContextT, P], Coro[T]],
+            Callable[Concatenate[ContextT, P], Coro[T]],
         ],
         /,
         **kwargs: Any,
@@ -380,7 +385,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         self.usage: Optional[str] = kwargs.get('usage')
         self.rest_is_raw: bool = kwargs.get('rest_is_raw', False)
         self.aliases: Union[List[str], Tuple[str]] = kwargs.get('aliases', [])
-        self.extras: Dict[Any, Any] = kwargs.get('extras', {})
+        self.extras: Dict[str, Any] = kwargs.get('extras', {})
 
         if not isinstance(self.aliases, (list, tuple)):
             raise TypeError("Aliases of a command must be a list or a tuple of strings.")
@@ -394,7 +399,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         except AttributeError:
             checks = kwargs.get('checks', [])
 
-        self.checks: List[UserCheck[Context[Any]]] = checks
+        self.checks: List[UserCheck[ContextT]] = checks
 
         try:
             cooldown = func.__commands_cooldown__
@@ -404,10 +409,10 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         if cooldown is None:
             buckets = CooldownMapping(cooldown, BucketType.default)
         elif isinstance(cooldown, CooldownMapping):
-            buckets: CooldownMapping[Context[Any]] = cooldown
+            buckets = cooldown
         else:
-            raise TypeError("Cooldown must be an instance of CooldownMapping or None.")
-        self._buckets: CooldownMapping[Context[Any]] = buckets
+            raise TypeError("Cooldown must be a an instance of CooldownMapping or None.")
+        self._buckets: CooldownMapping = buckets
 
         try:
             max_concurrency = func.__commands_max_concurrency__
@@ -452,15 +457,15 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
     @property
     def callback(
         self,
-    ) -> Union[Callable[Concatenate[CogT, Context[Any], P], Coro[T]], Callable[Concatenate[Context[Any], P], Coro[T]],]:
+    ) -> Union[Callable[Concatenate[CogT, Context, P], Coro[T]], Callable[Concatenate[Context, P], Coro[T]],]:
         return self._callback
 
     @callback.setter
     def callback(
         self,
         function: Union[
-            Callable[Concatenate[CogT, Context[Any], P], Coro[T]],
-            Callable[Concatenate[Context[Any], P], Coro[T]],
+            Callable[Concatenate[CogT, Context, P], Coro[T]],
+            Callable[Concatenate[Context, P], Coro[T]],
         ],
     ) -> None:
         self._callback = function
@@ -474,7 +479,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
 
         self.params: Dict[str, Parameter] = get_signature_parameters(function, globalns)
 
-    def add_check(self, func: UserCheck[Context[Any]], /) -> None:
+    def add_check(self, func: UserCheck[ContextT], /) -> None:
         """Adds a check to the command.
 
         This is the non-decorator interface to :func:`.check`.
@@ -495,7 +500,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
 
         self.checks.append(func)
 
-    def remove_check(self, func: UserCheck[Context[Any]], /) -> None:
+    def remove_check(self, func: UserCheck[ContextT], /) -> None:
         """Removes a check from the command.
 
         This function is idempotent and will not raise an exception
@@ -554,7 +559,6 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
     def _ensure_assignment_on_copy(self, other: Self) -> Self:
         other._before_invoke = self._before_invoke
         other._after_invoke = self._after_invoke
-        other.extras = self.extras
         if self.checks != other.checks:
             other.checks = self.checks.copy()
         if self._buckets.valid and not other._buckets.valid:
@@ -875,7 +879,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         if self._buckets.valid:
             dt = ctx.message.edited_at or ctx.message.created_at
             current = dt.replace(tzinfo=datetime.timezone.utc).timestamp()
-            bucket = self._buckets.get_bucket(ctx, current)
+            bucket = self._buckets.get_bucket(ctx.message, current)
             if bucket is not None:
                 retry_after = bucket.update_rate_limit(current)
                 if retry_after:
@@ -889,7 +893,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
 
         if self._max_concurrency is not None:
             # For this application, context can be duck-typed as a Message
-            await self._max_concurrency.acquire(ctx)
+            await self._max_concurrency.acquire(ctx)  # type: ignore
 
         try:
             if self.cooldown_after_parsing:
@@ -902,7 +906,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             await self.call_before_hooks(ctx)
         except:
             if self._max_concurrency is not None:
-                await self._max_concurrency.release(ctx)
+                await self._max_concurrency.release(ctx)  # type: ignore
             raise
 
     def is_on_cooldown(self, ctx: Context[BotT], /) -> bool:
@@ -925,7 +929,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
         if not self._buckets.valid:
             return False
 
-        bucket = self._buckets.get_bucket(ctx)
+        bucket = self._buckets.get_bucket(ctx.message)
         if bucket is None:
             return False
         dt = ctx.message.edited_at or ctx.message.created_at
@@ -945,7 +949,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             The invocation context to reset the cooldown under.
         """
         if self._buckets.valid:
-            bucket = self._buckets.get_bucket(ctx)
+            bucket = self._buckets.get_bucket(ctx.message)
             if bucket is not None:
                 bucket.reset()
 
@@ -970,7 +974,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
             If this is ``0.0`` then the command isn't on cooldown.
         """
         if self._buckets.valid:
-            bucket = self._buckets.get_bucket(ctx)
+            bucket = self._buckets.get_bucket(ctx.message)
             if bucket is None:
                 return 0.0
             dt = ctx.message.edited_at or ctx.message.created_at
@@ -1245,7 +1249,7 @@ class Command(_BaseCommand, Generic[CogT, P, T]):
                 # since we have no checks, then we just return True.
                 return True
 
-            return await discord.utils.async_all(predicate(ctx) for predicate in predicates)
+            return await discord.utils.async_all(predicate(ctx) for predicate in predicates)  # type: ignore
         finally:
             ctx.command = original
 
@@ -1444,7 +1448,7 @@ class GroupMixin(Generic[CogT]):
     def command(
         self: GroupMixin[CogT],
         name: str = ...,
-        cls: Type[CommandT] = ...,  # type: ignore  # previous overload handles case where cls is not set
+        cls: Type[CommandT] = ...,
         *args: Any,
         **kwargs: Any,
     ) -> Callable[
@@ -1504,7 +1508,7 @@ class GroupMixin(Generic[CogT]):
     def group(
         self: GroupMixin[CogT],
         name: str = ...,
-        cls: Type[GroupT] = ...,  # type: ignore  # previous overload handles case where cls is not set
+        cls: Type[GroupT] = ...,
         *args: Any,
         **kwargs: Any,
     ) -> Callable[
@@ -1696,7 +1700,7 @@ def command(
 @overload
 def command(
     name: str = ...,
-    cls: Type[CommandT] = ...,  # type: ignore  # previous overload handles case where cls is not set
+    cls: Type[CommandT] = ...,
     **attrs: Any,
 ) -> Callable[
     [
@@ -1766,7 +1770,7 @@ def group(
 @overload
 def group(
     name: str = ...,
-    cls: Type[GroupT] = ...,  # type: ignore  # previous overload handles case where cls is not set
+    cls: Type[GroupT] = ...,
     **attrs: Any,
 ) -> Callable[
     [
@@ -1874,9 +1878,9 @@ def check(predicate: UserCheck[ContextT], /) -> Check[ContextT]:
         The predicate to check if the command should be invoked.
     """
 
-    def decorator(func: Union[Command[Any, ..., Any], CoroFunc]) -> Union[Command[Any, ..., Any], CoroFunc]:
+    def decorator(func: Union[Command, CoroFunc]) -> Union[Command, CoroFunc]:
         if isinstance(func, Command):
-            func.checks.append(predicate)  # type: ignore
+            func.checks.append(predicate)
         else:
             if not hasattr(func, '__commands_checks__'):
                 func.__commands_checks__ = []
@@ -2155,7 +2159,8 @@ def has_permissions(**perms: bool) -> Check[Any]:
         raise TypeError(f"Invalid permission(s): {', '.join(invalid)}")
 
     def predicate(ctx: Context[BotT]) -> bool:
-        permissions = ctx.permissions
+        ch = ctx.channel
+        permissions = ch.permissions_for(ctx.author)  # type: ignore
 
         missing = [perm for perm, value in perms.items() if getattr(permissions, perm) != value]
 
@@ -2180,7 +2185,9 @@ def bot_has_permissions(**perms: bool) -> Check[Any]:
         raise TypeError(f"Invalid permission(s): {', '.join(invalid)}")
 
     def predicate(ctx: Context[BotT]) -> bool:
-        permissions = ctx.bot_permissions
+        guild = ctx.guild
+        me = guild.me if guild is not None else ctx.bot.user
+        permissions = ctx.channel.permissions_for(me)  # type: ignore
 
         missing = [perm for perm, value in perms.items() if getattr(permissions, perm) != value]
 
@@ -2395,7 +2402,7 @@ def is_nsfw() -> Check[Any]:
 def cooldown(
     rate: int,
     per: float,
-    type: Union[BucketType, Callable[[Context[Any]], Any]] = BucketType.default,
+    type: Union[BucketType, Callable[[Message], Any]] = BucketType.default,
 ) -> Callable[[T], T]:
     """A decorator that adds a cooldown to a :class:`.Command`
 
@@ -2416,7 +2423,7 @@ def cooldown(
         The number of times a command can be used before triggering a cooldown.
     per: :class:`float`
         The amount of seconds to wait for a cooldown when it's been triggered.
-    type: Union[:class:`.BucketType`, Callable[[:class:`.Context`], Any]]
+    type: Union[:class:`.BucketType`, Callable[[:class:`.Message`], Any]]
         The type of cooldown to have. If callable, should return a key for the mapping.
 
         .. versionchanged:: 1.7
@@ -2434,8 +2441,8 @@ def cooldown(
 
 
 def dynamic_cooldown(
-    cooldown: Callable[[Context[Any]], Optional[Cooldown]],
-    type: Union[BucketType, Callable[[Context[Any]], Any]],
+    cooldown: Union[BucketType, Callable[[Message], Any]],
+    type: BucketType,
 ) -> Callable[[T], T]:
     """A decorator that adds a dynamic cooldown to a :class:`.Command`
 
@@ -2459,7 +2466,7 @@ def dynamic_cooldown(
 
     Parameters
     ------------
-    cooldown: Callable[[:class:`.Context`], Optional[:class:`~discord.app_commands.Cooldown`]]
+    cooldown: Callable[[:class:`.discord.Message`], Optional[:class:`~discord.app_commands.Cooldown`]]
         A function that takes a message and returns a cooldown that will
         apply to this invocation or ``None`` if the cooldown should be bypassed.
     type: :class:`.BucketType`
