@@ -184,6 +184,13 @@ class ScheduledEvent(Hashable):
         """:class:`str`: The url for the scheduled event."""
         return f'https://discord.com/events/{self.guild_id}/{self.id}'
 
+    async def __modify_status(self, status: EventStatus, reason: Optional[str], /) -> ScheduledEvent:
+        payload = {'status': status.value}
+        data = await self._state.http.edit_scheduled_event(self.guild_id, self.id, **payload, reason=reason)
+        s = ScheduledEvent(state=self._state, data=data)
+        s._users = self._users
+        return s
+
     async def start(self, *, reason: Optional[str] = None) -> ScheduledEvent:
         """|coro|
 
@@ -217,7 +224,7 @@ class ScheduledEvent(Hashable):
         if self.status is not EventStatus.scheduled:
             raise ValueError('This scheduled event is already running.')
 
-        return await self.edit(status=EventStatus.active, reason=reason)
+        return await self.__modify_status(EventStatus.active, reason)
 
     async def end(self, *, reason: Optional[str] = None) -> ScheduledEvent:
         """|coro|
@@ -252,7 +259,7 @@ class ScheduledEvent(Hashable):
         if self.status is not EventStatus.active:
             raise ValueError('This scheduled event is not active.')
 
-        return await self.edit(status=EventStatus.ended, reason=reason)
+        return await self.__modify_status(EventStatus.ended, reason)
 
     async def cancel(self, *, reason: Optional[str] = None) -> ScheduledEvent:
         """|coro|
@@ -287,7 +294,7 @@ class ScheduledEvent(Hashable):
         if self.status is not EventStatus.scheduled:
             raise ValueError('This scheduled event is already running.')
 
-        return await self.edit(status=EventStatus.cancelled, reason=reason)
+        return await self.__modify_status(EventStatus.cancelled, reason)
 
     async def edit(
         self,
@@ -317,7 +324,9 @@ class ScheduledEvent(Hashable):
         description: :class:`str`
             The description of the scheduled event.
         channel: Optional[:class:`~discord.abc.Snowflake`]
-            The channel to put the scheduled event in.
+            The channel to put the scheduled event in. If the channel is
+            a :class:`StageInstance` or :class:`VoiceChannel` then
+            it automatically sets the entity type.
 
             Required if the entity type is either :attr:`EntityType.voice` or
             :attr:`EntityType.stage_instance`.
@@ -336,7 +345,9 @@ class ScheduledEvent(Hashable):
         privacy_level: :class:`PrivacyLevel`
             The privacy level of the scheduled event.
         entity_type: :class:`EntityType`
-            The new entity type.
+            The new entity type. If the channel is a :class:`StageInstance`
+            or :class:`VoiceChannel` then this is automatically set to the
+            appropriate entity type.
         status: :class:`EventStatus`
             The new status of the scheduled event.
         image: Optional[:class:`bytes`]
@@ -400,6 +411,12 @@ class ScheduledEvent(Hashable):
             image_as_str: Optional[str] = _bytes_to_base64_data(image) if image is not None else image
             payload['image'] = image_as_str
 
+        entity_type = entity_type or getattr(channel, '_scheduled_event_entity_type', MISSING)
+        if entity_type is None:
+            raise TypeError(
+                f'invalid GuildChannel type passed, must be VoiceChannel or StageChannel not {channel.__class__!r}'
+            )
+
         if entity_type is not MISSING:
             if not isinstance(entity_type, EntityType):
                 raise TypeError('entity_type must be of type EntityType')
