@@ -183,7 +183,6 @@ class Shard:
             coro = DiscordWebSocket.from_client(
                 self._client,
                 resume=exc.resume,
-                gateway=None if not exc.resume else self.ws.gateway,
                 shard_id=self.id,
                 session=self.ws.session_id,
                 sequence=self.ws.sequence,
@@ -309,14 +308,6 @@ class AutoShardedClient(Client):
     if this is used. By default, when omitted, the client will launch shards from
     0 to ``shard_count - 1``.
 
-    .. container:: operations
-
-        .. describe:: async with x
-
-            Asynchronously initialises the client and automatically cleans up.
-
-            .. versionadded:: 2.0
-
     Attributes
     ------------
     shard_ids: Optional[List[:class:`int`]]
@@ -417,9 +408,6 @@ class AutoShardedClient(Client):
         ret.launch()
 
     async def launch_shards(self) -> None:
-        if self.is_closed():
-            return
-
         if self.shard_count is None:
             self.shard_count: int
             self.shard_count, gateway = await self.http.get_bot_gateway()
@@ -472,7 +460,12 @@ class AutoShardedClient(Client):
             return
 
         self._closed = True
-        await self._connection.close()
+
+        for vc in self.voice_clients:
+            try:
+                await vc.disconnect(force=True)
+            except Exception:
+                pass
 
         to_close = [asyncio.ensure_future(shard.close(), loop=self.loop) for shard in self.__shards.values()]
         if to_close:
