@@ -73,7 +73,6 @@ from .scheduled_event import ScheduledEvent
 from .stage_instance import StageInstance
 from .threads import Thread, ThreadMember
 from .sticker import GuildSticker
-from .automod import AutoModRule, AutoModAction
 
 if TYPE_CHECKING:
     from .abc import PrivateChannel
@@ -83,9 +82,8 @@ if TYPE_CHECKING:
     from .voice_client import VoiceProtocol
     from .client import Client
     from .gateway import DiscordWebSocket
-    from .app_commands import CommandTree, Translator
+    from .app_commands import CommandTree
 
-    from .types.automod import AutoModerationRule, AutoModerationActionExecution
     from .types.snowflake import Snowflake
     from .types.activity import Activity as ActivityPayload
     from .types.channel import DMChannel as DMChannelPayload
@@ -95,7 +93,6 @@ if TYPE_CHECKING:
     from .types.guild import Guild as GuildPayload
     from .types.message import Message as MessagePayload, PartialMessage as PartialMessagePayload
     from .types import gateway as gw
-    from .types.command import GuildApplicationCommandPermissions as GuildApplicationCommandPermissionsPayload
 
     T = TypeVar('T')
     Channel = Union[GuildChannel, VocalGuildChannel, PrivateChannel, PartialMessageable]
@@ -245,10 +242,9 @@ class ConnectionState:
         self._status: Optional[str] = status
         self._intents: Intents = intents
         self._command_tree: Optional[CommandTree] = None
-        self._translator: Optional[Translator] = None
 
         if not intents.members or cache_flags._empty:
-            self.store_user = self.store_user_no_intents
+            self.store_user = self.store_user_no_intents  # type: ignore # This reassignment is on purpose
 
         self.parsers: Dict[str, Callable[[Any], None]]
         self.parsers = parsers = {}
@@ -258,19 +254,6 @@ class ConnectionState:
 
         self.clear()
 
-    async def close(self) -> None:
-        for voice in self.voice_clients:
-            try:
-                await voice.disconnect(force=True)
-            except Exception:
-                # if an error happens during disconnects, disregard it.
-                pass
-
-        if self._translator:
-            await self._translator.unload()
-
-        # Purposefully don't call `clear` because users rely on cache being available post-close
-
     def clear(self, *, views: bool = True) -> None:
         self.user: Optional[ClientUser] = None
         self._users: weakref.WeakValueDictionary[int, User] = weakref.WeakValueDictionary()
@@ -392,8 +375,8 @@ class ConnectionState:
         return self._view_store.persistent_views
 
     @property
-    def guilds(self) -> Sequence[Guild]:
-        return utils.SequenceProxy(self._guilds.values())
+    def guilds(self) -> List[Guild]:
+        return list(self._guilds.values())
 
     def _get_guild(self, guild_id: Optional[int]) -> Optional[Guild]:
         # the keys of self._guilds are ints
@@ -417,12 +400,12 @@ class ConnectionState:
         del guild
 
     @property
-    def emojis(self) -> Sequence[Emoji]:
-        return utils.SequenceProxy(self._emojis.values())
+    def emojis(self) -> List[Emoji]:
+        return list(self._emojis.values())
 
     @property
-    def stickers(self) -> Sequence[GuildSticker]:
-        return utils.SequenceProxy(self._stickers.values())
+    def stickers(self) -> List[GuildSticker]:
+        return list(self._stickers.values())
 
     def get_emoji(self, emoji_id: Optional[int]) -> Optional[Emoji]:
         # the keys of self._emojis are ints
@@ -433,8 +416,8 @@ class ConnectionState:
         return self._stickers.get(sticker_id)  # type: ignore
 
     @property
-    def private_channels(self) -> Sequence[PrivateChannel]:
-        return utils.SequenceProxy(self._private_channels.values())
+    def private_channels(self) -> List[PrivateChannel]:
+        return list(self._private_channels.values())
 
     def _get_private_channel(self, channel_id: Optional[int]) -> Optional[PrivateChannel]:
         try:
@@ -1096,46 +1079,6 @@ class ConnectionState:
         guild.stickers = tuple(map(lambda d: self.store_sticker(guild, d), data['stickers']))
         self.dispatch('guild_stickers_update', guild, before_stickers, guild.stickers)
 
-    def parse_auto_moderation_rule_create(self, data: AutoModerationRule) -> None:
-        guild = self._get_guild(int(data['guild_id']))
-        if guild is None:
-            _log.debug('AUTO_MODERATION_RULE_CREATE referencing an unknown guild ID: %s. Discarding.', data['guild_id'])
-            return
-
-        rule = AutoModRule(data=data, guild=guild, state=self)
-
-        self.dispatch('automod_rule_create', rule)
-
-    def parse_auto_moderation_rule_update(self, data: AutoModerationRule) -> None:
-        guild = self._get_guild(int(data['guild_id']))
-        if guild is None:
-            _log.debug('AUTO_MODERATION_RULE_UPDATE referencing an unknown guild ID: %s. Discarding.', data['guild_id'])
-            return
-
-        rule = AutoModRule(data=data, guild=guild, state=self)
-
-        self.dispatch('automod_rule_update', rule)
-
-    def parse_auto_moderation_rule_delete(self, data: AutoModerationRule) -> None:
-        guild = self._get_guild(int(data['guild_id']))
-        if guild is None:
-            _log.debug('AUTO_MODERATION_RULE_DELETE referencing an unknown guild ID: %s. Discarding.', data['guild_id'])
-            return
-
-        rule = AutoModRule(data=data, guild=guild, state=self)
-
-        self.dispatch('automod_rule_delete', rule)
-
-    def parse_auto_moderation_action_execution(self, data: AutoModerationActionExecution) -> None:
-        guild = self._get_guild(int(data['guild_id']))
-        if guild is None:
-            _log.debug('AUTO_MODERATION_ACTION_EXECUTION referencing an unknown guild ID: %s. Discarding.', data['guild_id'])
-            return
-
-        execution = AutoModAction(data=data, state=self)
-
-        self.dispatch('automod_action', execution)
-
     def _get_create_guild(self, data: gw.GuildCreateEvent) -> Guild:
         if data.get('unavailable') is False:
             # GUILD_CREATE with unavailable in the response
@@ -1343,7 +1286,7 @@ class ConnectionState:
             _log.debug('GUILD_INTEGRATIONS_UPDATE referencing an unknown guild ID: %s. Discarding.', data['guild_id'])
 
     def parse_integration_create(self, data: gw.IntegrationCreateEvent) -> None:
-        guild_id = int(data['guild_id'])
+        guild_id = int(data.pop('guild_id'))
         guild = self._get_guild(guild_id)
         if guild is not None:
             cls, _ = _integration_factory(data['type'])
@@ -1353,7 +1296,7 @@ class ConnectionState:
             _log.debug('INTEGRATION_CREATE referencing an unknown guild ID: %s. Discarding.', guild_id)
 
     def parse_integration_update(self, data: gw.IntegrationUpdateEvent) -> None:
-        guild_id = int(data['guild_id'])
+        guild_id = int(data.pop('guild_id'))
         guild = self._get_guild(guild_id)
         if guild is not None:
             cls, _ = _integration_factory(data['type'])
@@ -1490,10 +1433,6 @@ class ConnectionState:
         else:
             _log.debug('SCHEDULED_EVENT_USER_REMOVE referencing unknown guild ID: %s. Discarding.', data['guild_id'])
 
-    def parse_application_command_permissions_update(self, data: GuildApplicationCommandPermissionsPayload):
-        raw = RawAppCommandPermissionsUpdateEvent(data=data, state=self)
-        self.dispatch('raw_app_command_permissions_update', raw)
-
     def parse_voice_state_update(self, data: gw.VoiceStateUpdateEvent) -> None:
         guild = self._get_guild(utils._get_as_snowflake(data, 'guild_id'))
         channel_id = utils._get_as_snowflake(data, 'channel_id')
